@@ -1,11 +1,9 @@
-/*  $Id$
-
-    Part of SWI-Prolog
+/*  Part of SWI-Prolog
 
     Author:        Jan Wielemaker
-    E-mail:        J.Wielemaker@cs.vu.nl
+    E-mail:        J.Wielemaker@vu.nl
     WWW:           http://www.swi-prolog.org
-    Copyright (C): 1985-2011, University of Amsterdam
+    Copyright (C): 1985-2012, University of Amsterdam
 			      VU University Amsterdam
 
     This program is free software; you can redistribute it and/or
@@ -43,6 +41,7 @@
 	  ]).
 :- use_module(library(error)).
 :- use_module(library(lists)).
+:- set_prolog_flag(generate_debug_info, false).
 
 :- meta_predicate
 	assertion(0),
@@ -69,7 +68,7 @@ topics the user can  select  desired   messages.  Debug  statements  are
 removed when the code is compiled for optimization.
 
 See manual for details. With XPCE, you can use the call below to start a
-graphical monitorring tool.
+graphical monitoring tool.
 
 ==
 ?- prolog_ide(debug_monitor).
@@ -85,8 +84,20 @@ program explicit, trapping the debugger if the condition does not hold.
 %%	debugging(-Topic) is nondet.
 %%	debugging(?Topic, ?Bool) is nondet.
 %
-%	Check whether we are debugging Topic or enumerate the topics we
-%	are debugging.
+%	Examine debug topics. The form debugging(+Topic)  may be used to
+%	perform more complex debugging tasks.   A typical usage skeleton
+%	is:
+%
+%	  ==
+%		(   debugging(mytopic)
+%		->  <perform debugging actions>
+%		;   true
+%		),
+%		...
+%	  ==
+%
+%	The other two calls are intended to examine existing and enabled
+%	debugging tokens and are typically not used in user programs.
 
 debugging(Topic) :-
 	debugging(Topic, true, _To).
@@ -100,7 +111,7 @@ debugging(Topic, Bool) :-
 %	Add/remove a topic from being   printed.  nodebug(_) removes all
 %	topics. Gives a warning if the topic is not defined unless it is
 %	used from a directive. The latter allows placing debug topics at
-%	the start a a (load-)file without warnings.
+%	the start of a (load-)file without warnings.
 %
 %	For debug/1, Topic can be  a  term   Topic  >  Out, where Out is
 %	either a stream or  stream-alias  or   a  filename  (atom). This
@@ -173,12 +184,12 @@ list_debug_topics :-
 	;   true
 	).
 
-%%	debug_message_context(What) is det.
+%%	debug_message_context(+What) is det.
 %
 %	Specify additional context for debug messages.   What  is one of
-%	+Context or -Context and Context is   one of =thread=. =time= or
-%	time(Format),  where  Format  is    a  format-specification  for
-%	format_time/3 (default is =|%T.%3f|=).   Initially, debug/3 show
+%	+Context or -Context, and Context is  one of =thread=, =time= or
+%	time(Format),  where  Format  is    a  format specification  for
+%	format_time/3 (default is =|%T.%3f|=).  Initially, debug/3 shows
 %	only thread information.
 
 debug_message_context(+Topic) :- !,
@@ -200,16 +211,17 @@ valid_topic(X, _, _) :-
 
 %%	debug(+Topic, +Format, :Args) is det.
 %
-%	Similar to format/3 to =user_error=, but only prints if Topic is
-%	activated through debug/1. Args is a  meta-argument to deal with
-%	goal for the @-command.  Output  is   first  handed  to the hook
+%	Format a message if debug topic  is enabled. Similar to format/3
+%	to =user_error=, but only prints if   Topic is activated through
+%	debug/1. Args is a  meta-argument  to   deal  with  goal for the
+%	@-command.   Output   is   first    handed     to    the    hook
 %	prolog:debug_print_hook/3.  If  this  fails,    Format+Args   is
 %	translated  to  text   using    the   message-translation   (see
 %	print_message/2) for the  term  debug(Format,   Args)  and  then
 %	printed to every matching destination   (controlled  by debug/1)
 %	using print_message_lines/3.
 %
-%	The message is preceeded by '% ' and terminated with a newline.
+%	The message is preceded by '% ' and terminated with a newline.
 %
 %	@see	format/3.
 
@@ -234,11 +246,11 @@ debug(_, _, _).
 print_debug(Topic, _To, Format, Args) :-
 	prolog:debug_print_hook(Topic, Format, Args), !.
 print_debug(_, [], _, _) :- !.
-print_debug(_, To, Format, Args) :-
+print_debug(Topic, To, Format, Args) :-
 	phrase('$messages':translate_message(debug(Format, Args)), Lines),
 	(   member(T, To),
 	    debug_output(T, Stream),
-	    print_message_lines(Stream, '% ', Lines),
+	    print_message_lines(Stream, kind(debug(Topic)), Lines),
 	    fail
 	;   true
 	).
@@ -262,14 +274,14 @@ debug_output(File, Stream) :-
 %%	assertion(:Goal) is det.
 %
 %	Acts similar to C assert()  macro.  It   has  no  effect if Goal
-%	succeeds. If Goal fails or throws   and exception, the following
+%	succeeds. If Goal fails or throws    an exception, the following
 %	steps are taken:
 %
 %	  * call prolog:assertion_failed/2.  If prolog:assertion_failed/2
 %	    fails, then:
 %
 %	    - If this is an interactive toplevel thread, print a
-%	      message, the stack-trace and finally traps the debugger.
+%	      message, the stack-trace, and finally trap the debugger.
 %	    - Otherwise, throw error(assertion_error(Reason, G),_) where
 %	      Reason is one of =fail= or the exception raised.
 
@@ -373,6 +385,6 @@ show_time_context -->
 %
 %	This hook is called if the Goal  of assertion/1 fails. Reason is
 %	unified with either =fail= if Goal simply failed or an exception
-%	ball otherwise. If this hook  fails,   the  default behaviour is
+%	call otherwise. If this hook  fails,   the  default behaviour is
 %	activated.  If  the  hooks  throws  an   exception  it  will  be
 %	propagated into the caller of assertion/1.
