@@ -19,7 +19,7 @@
 
     You should have received a copy of the GNU General Public
     License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
     As a special exception, if you link this library with other files,
     compiled with a Free Software compiler, to produce an executable, this
@@ -37,8 +37,7 @@
 	    assert_static/1,		% :Term
 	    source/0,
 	    yap_flag/2,			% +Flag, +Value
-	    yap_style_check/1,		% +Style
-	    yap_initialization/1	% :Goal
+	    yap_style_check/1		% +Style
 	  ]).
 
 /** <module> YAP Compatibility module
@@ -111,8 +110,6 @@ yap_expansion(if(Goal, Then, Else),
 	      (Goal *-> Then; Else)).
 yap_expansion(style_check(Style),
 	      yap_style_check(Style)).
-yap_expansion(initialization(Goal),
-	      yap_initialization(Goal)).
 
 
 		 /*******************************
@@ -266,30 +263,6 @@ yap_style_check(Style) :-
 	fixme_true(yap_style_check(Style)).
 
 
-%%	yap_initialization(:Goal) is det.
-%
-%	Register a goal to be ran `after preparing the Prolog text
-%	for execution'.  Currently we interpret this as at the end
-%	of the file.
-
-:- dynamic
-	yap_init_goal/2.		% +File, :Goal
-
-yap_initialization(Goal) :-
-	prolog_load_context(file, File),
-	assert(yap_init_goal(File, Goal)).
-
-user:message_hook(load_file(done(_Level,
-				 file(_File, Absolute),
-				 _Action,
-				 _LM,
-				 _TimeUsed,
-				 _HeapUsed)),
-		  _Kind, _Lines) :-
-	retract(yap_init_goal(Absolute, Goal)),
-	system:initialization(Goal).
-
-
 		 /*******************************
 		 *	   UNIMPLEMENTED		*
 		 *******************************/
