@@ -43,15 +43,21 @@
 #define	MSG_SPARE_STACK		 14
 #define	MSG_THREAD		 15
 #define MSG_THROW		 16
-#define MSG_SRCLOC		 17
-#define MSG_PROC		 18
+#define MSG_CALL		 17
+#define MSG_SRCLOC		 18
+#define MSG_PROC		 19
 
-#define MSG_COMP_ARGVAR		 19
-#define MSG_UNLOAD		 20
-#define MSG_INDEX_FIND		 21
-#define MSG_INDEX_UPDATE	 22
-#define MSG_JIT			 23
-#define MSG_TRACE		 24
+#define MSG_COMP_ARGVAR		 20
+#define MSG_UNLOAD		 21
+#define MSG_INDEX_FIND		 22
+#define MSG_INDEX_UPDATE	 23
+#define MSG_JIT			 24
+#define MSG_TRACE		 25
+
+#define MSG_QLF_PATH		 26
+#define MSG_QUEUE		 27
+#define MSG_QUEUE_WAIT		 28
+#define MSG_SIGNAL		 29
 
 						/* GC messages */
 #define	MSG_AGC			 100
