@@ -792,12 +792,16 @@ PL_unify_number__LD(term_t t, Number n ARG_LD)
 #ifdef O_GMP
     case V_MPQ:
     { word w;
+      term_t tmp;
       int rc;
 
+      if ( !(tmp=PL_new_term_ref()) )
+	return FALSE;
       if ( (rc=put_number(&w, n, ALLOW_GC PASS_LD)) != TRUE )
 	return raiseStackOverflow(rc);
 
-      return _PL_unify_atomic(t, w);
+      *valTermRef(tmp) = w;
+      return PL_unify(t, tmp);
     }
 #endif
     case V_FLOAT:
